| bincorr2commonprob | R Documentation |
Compute a matrix of common probabilities for a binary random vector from given marginal probabilities and correlations.
bincorr2commonprob(margprob, bincorr)
margprob |
vector of marginal probabilities. |
bincorr |
matrix of binary correlations. |
The matrix of common probabilities. This has the probabilities that
variable i equals 1 in element (i,i), and the joint
probability that variables i and j both equal 1 in element
(i,j) (if i \ne j).
Friedrich Leisch
bindata::Leisch+Weingessel+Hornik:1998
commonprob2sigma,
simul.commonprob.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.